﻿using System;

/// @author  Vesa Lappalainen
/// @version 11.10.2011
///
/// <summary>
/// Tutkitaan matriiseja
/// </summary>
public class Matriisit
{
    /// <summary>
    /// Tutkitaan matriiseja
    /// </summary>
    static void Main()
    {
        int[,] mat = {
                       {2,1,2},
                       {3,4,2},
                       {1,0,1},
                       {1,8,9}
                     };
        // int[,] mat2 = new int[6, 5];

        int lkm = MonellakoRivilla(mat, 1);
        Console.WriteLine("1 oli {0} rivillä", lkm);
    }


    /// <summary>
    /// Lasketaan monellako rivillä taulukossa esiintyy etsittävä luku.
    /// Jos luku on useasti samalla rivillä, rivi lasketaan yhden kerran.
    /// </summary>
    /// <param name="mat">matriisi, josta lukua etsitään</param>
    /// <param name="etsittava">luku jota etsitään</param>
    /// <returns>monellako rivillä etsittävä oli</returns>
    /// <example>
    /// <pre name="test">
    ///  int[,] t = {{2,1,2},
    ///              {3,4,2},
    ///              {1,0,1},
    ///              {1,8,9}};
    ///  MonellakoRivilla(t,2) === 2;
    ///  MonellakoRivilla(t,5) === 0;
    ///  MonellakoRivilla(t,0) === 1;
    ///  MonellakoRivilla(t,1) === 3;
    ///  MonellakoRivilla(new int[0,0],1) === 0;
    /// </pre>
    /// </example>
    public static int MonellakoRivilla(int[,] mat, int etsittava)
    {
        int riveja = mat.GetLength(0);
        int sarkkeita = mat.GetLength(1);
        int lkm = 0;

        for (int iy = 0; iy < riveja; iy++)
            for (int ix = 0; ix < sarkkeita; ix++)
                if (mat[iy, ix] == etsittava)
                {
                    lkm++;
                    break;
                }
        return lkm;
    }


    /// <summary>
    /// Lasketaan taulukon alkioiden summa
    /// </summary>
    /// <param name="mat">taulukko jonka alkioiden summa lasketaan</param>
    /// <returns>alkioiden summa</returns>
    /// <example>
    /// <pre name="test">
    ///  int[,] t = {{2,1,2},{3,4,2},{1,0,1},{1,8,9}};
    ///  Matriisit.Summa(t) === 34;
    ///  Matriisit.Summa(new int[1,1]{{5}}) === 5;
    ///  Matriisit.Summa(new int[0,0]) === 0;
    /// </pre>
    /// </example>
    public static int Summa(int[,] mat)
    {
        int summa = 0;
        foreach (int luku in mat) summa += luku;
        return summa;
    }
}
